@@ -5,7 +5,8 @@ from pydantic import (
 
 from typing import Optional, List
 
-from ..generics import Image
+from captur_ml_sdk.dtypes.generics import Image
+from captur_ml_sdk.dtypes.interfaces.validators import check_images_or_imagefile_has_data
 
 
 class OfflinePreRunEventData_MetaField(BaseModel):
@@ -21,11 +22,4 @@ class OfflinePreRunEventData(BaseModel):
     model_id: str
     labels_source: Optional[str]
 
-    @root_validator
-    def check_images_or_imagefile_has_data(cls, values):
-        if not values.get('images') and not values.get('imagesfile'):
-            raise ValueError(
-                "At least one of 'images' and 'imagesfile' must be set."
-            )
-
-        return values
+    root_validator(check_images_or_imagefile_has_data)
