@@ -321,7 +321,7 @@ def check_file_exists(filepath):
     return gcs_file_system.exists(filepath)
 
 
-def get_dataset_id_from_model_id(model_id):
+def get_dataset_id_from_model_id(model_name, model_id):
     """
     Returns the id of the dataset used to train the model with id 'model_id'.
     ----------------
@@ -333,4 +333,9 @@ def get_dataset_id_from_model_id(model_id):
     """
     model_data = read_json_from_gcp_storage(
         file_path="captur-ml/models/model_dataset_mapping.json")
-    return model_data.get(model_id)
+    model_versions = model_data.get("model_name")
+    dataset_id = None
+    for version in model_versions:
+        if version.get("model_id") == model_id:
+            dataset_id = version.get("dataset_id")
+    return dataset_id
